.. rst-class:: detail

Stop
===============

.. currentmodule:: compas_rrc

.. autoclass:: Stop

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~Stop.__init__
        ~Stop.from_msg
    
    